@@ -14,13 +14,13 @@
 """Provides common functionality for packing ANN models into a czann file."""
 import os
 import json
-from io import StringIO
+from io import StringIO, BytesIO
 from typing import Optional, Union, TYPE_CHECKING
 from zipfile import ZipFile
 
-# Ignore flake8 imported but unused warnings (does not recognize non-runtime check). Checked by mypy
 if TYPE_CHECKING:
-    from czmodel.model_metadata import ModelMetadata  # noqa: F401
+    from czmodel.model_metadata import ModelMetadata
+    from czmodel.legacy_model_metadata import ModelMetadata as LegacyModelMetadata
 
 
 def zip_directory(directory: str, zip_file: ZipFile) -> None:
@@ -45,7 +45,7 @@ def create_model_zip(
     model: Union[str, bytes, memoryview],
     model_metadata: "ModelMetadata",
     output_path: str,
-    license_file: Optional[str] = None
+    license_file: Optional[str] = None,
 ) -> None:
     """Creates a CZANN file from a given ModelMetadata.
 
@@ -79,3 +79,43 @@ def create_model_zip(
                 license_file,
                 arcname=os.path.split(license_file)[1],
             )
+
+
+def create_legacy_model_zip(
+    model: Union[str, bytes, memoryview],
+    model_metadata: "LegacyModelMetadata",
+    output_path: str,
+    license_file: Optional[str] = None,
+) -> None:
+    """Creates a CZModel file from a given ModelMetadata.
+
+    Args:
+        model: The Keras model to be packed.
+        model_metadata: The meta data describing the CZModel to be generated.
+        output_path: The path of the CZModel file to be generated.
+        license_file: The path to a license file to be included in the model.
+    """
+    # Append correct extension if necessary
+    if not output_path.lower().endswith(".czseg"):
+        output_path = output_path + ".czseg"
+
+    # Create ZIP file
+    with ZipFile(output_path, mode="w") as zf:
+        # Write model xml file
+        buffer = BytesIO()
+        model_metadata.to_xml().write(buffer, encoding="utf-8", xml_declaration=True)
+        zf.writestr(str(model_metadata.model_id) + ".xml", buffer.getvalue())
+        # Pack and rename proto-buffer file
+        arcname = str(model_metadata.model_id) + ".model"
+        if isinstance(model, str):
+            zf.write(model, arcname=arcname)
+        else:
+            zf.writestr(arcname, model)
+        # Pack license file
+        if license_file is not None:
+            zf.write(
+                license_file,
+                arcname=os.path.split(license_file)[1],
+            )
+        # Write empty file with model id
+        zf.writestr("modelid=" + str(model_metadata.model_id), "")
